==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPattern.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class
RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPattern(
    public val all:
    RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPatternAll? =
        null,
    public val excludedCookies: List<String>? = null,
    public val includedCookies: List<String>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPattern):
            RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPattern =
            RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPattern(
                all = javaType.all().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPatternAll.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                excludedCookies = javaType.excludedCookies().map({ args0 -> args0 }),
                includedCookies = javaType.includedCookies().map({ args0 -> args0 }),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/outputs/RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPattern.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class
RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPattern(
    public val all: RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPatternAll? =
        null,
    public val excludedCookies: List<String>? = null,
    public val includedCookies: List<String>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.wafv2.outputs.RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPattern): RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPattern =
            RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPattern(
                all = javaType.all().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.wafv2.kotlin.outputs.RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchCookiesMatchPatternAll.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                excludedCookies = javaType.excludedCookies().map({ args0 -> args0 }),
                includedCookies = javaType.includedCookies().map({ args0 -> args0 }),
            )
    }
}
